from sqlitedict import SqliteDict
import orjson
import numpy as np


def lookup_cached_ids(l2_ids, cache_file):

    l2means = []
    is_cached = []

    with SqliteDict(cache_file, decode=orjson.loads, flag='c') as cache_dict:
        for l2id in l2_ids:
            loc = cache_dict.get(str(l2id), None)
            if loc is not None:
                l2means.append(loc)
                is_cached.append(True)
            else:
                is_cached.append(False)

    if len(l2means) > 0:
        l2means = np.vstack(l2means)
    else:
        l2means = np.zeros((0, 3), dtype=float)

    return l2means, np.array(is_cached)


def save_ids_to_cache(l2_ids, l2_locs, cache_file):
    """Save computed locations back to the l2 cache.

    Parameters
    ----------
    l2_ids : list-like
        List of N layer 2 ids
    l2_locs : np.array
        Nx3 array of locations
    cache_file : str

    """
    ii = 0
    with SqliteDict(cache_file, encode=orjson.dumps, flag='c') as cache_dict:
        for k, v in zip(l2_ids, l2_locs):
            if not np.any(np.isnan(v)):
                cache_dict[str(k)] = v.tolist()
        cache_dict.commit()
    pass



import setuptools
import re
import os
import codecs

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


def read(*parts):
    with codecs.open(os.path.join(here, *parts), 'r') as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


with open('requirements.txt', 'r') as f:
    required = f.read().splitlines()
dependency_links = []
del_ls = []
for i_l in range(len(required)):
    l = required[i_l]
    if l.startswith("-e"):
        dependency_links.append(l.split("-e ")[-1])
        del_ls.append(i_l)
        required.append(l.split("=")[-1])

for i_l in del_ls[::-1]:
    del required[i_l]

setuptools.setup(
    name="pcg_skel",
    version=find_version("pcg_skel", "__init__.py"),
    author="Casey Schneider-mizell",
    author_email="caseys@alleninstitute.org",
    description="Skeletonization using the pychunkedgraph",
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=required,
    include_package_data=True,
    dependency_links=dependency_links,
    url='https://github.com/AllenInstitute/pcg_skel',
    packages=["pcg_skel"]
)
